Projy — Projy 0.1 documentation

### Navigation

- index
- next |
- Projy 0.1 documentation »

# Projy

Projy is a template-based skeleton generator. In one command line, you can generate project skeletons like Python packages, LaTeX document or any file structure composed of directories and files.

Each file is generated by a different template. It uses the simple core templating system from Python, nothing fancy on that part. You can easily add new templates and new ways to collect data to insert in the created files. As much as possible, Projy tries to be simple to use and extend.

# Content

- Installation
  - Pip and Distribute
  - Install with git
- Usage
  - An example
  - Options
- Available templates
  - Project templates
  - File templates
  - Collectors
- Extending Projy
  - Project templates
  - File templates
  - Data collectors

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- Projy 0.1 documentation »